Revert "fixed memory free apis"

This reverts commit 805dbd6d90.


[ROCm/clr commit: 1fa4d0d4b9]
此提交包含在:
Aditya Atluri
2016-03-21 10:36:11 -05:00
父節點 4ca3e4e20e
當前提交 70d2a03efd
共有 5 個檔案被更改,包括 7 行新增81 行删除
+2 -2
查看文件
@@ -688,10 +688,10 @@ hipError_t hipHostAlloc(void** ptr, size_t size, unsigned int flags) __attribute
*
* @param[out] dstPtr Device Pointer mapped to passed host pointer
* @param[in] hstPtr Host Pointer allocated through hipHostAlloc
* @param[in] flags Flags to be passed for extension
* @param[in] size Requested memory size
* @return Error code
*/
hipError_t hipHostGetDevicePointer(void** devPtr, void* hstPtr, unsigned int flags) ;
hipError_t hipHostGetDevicePointer(void** devPtr, void* hstPtr, size_t size) ;
/**
* @brief Get flags associated with host pointer
-2
查看文件
@@ -149,8 +149,6 @@ typedef enum hipError_t {
,hipErrorInvalidResourceHandle ///< Resource handle (hipEvent_t or hipStream_t) invalid.
,hipErrorInvalidDevice ///< DeviceID must be in range 0...#compute-devices.
,hipErrorInvalidMemcpyDirection ///< Invalid memory copy direction
,hipErrorInvalidDevicePointer ///< Invalid Device Pointer
,hipErrorInitializationError ///< TODO comment from hipErrorInitializationError
,hipErrorNoDevice ///< Call to hipGetDeviceCount returned 0 devices
,hipErrorNotReady ///< Indicates that asynchronous operations enqueued earlier are not ready. This is not actually an error, but is used to distinguish from hipSuccess (which indicates completion). APIs that return this error include hipEventQuery and hipStreamQuery.
+5 -22
查看文件
@@ -2603,24 +2603,15 @@ hipError_t hipFree(void* ptr)
// TODO - ensure this pointer was created by hipMalloc and not hipMallocHost
std::call_once(hip_initialized, ihipInit);
hipError_t hipStatus = hipErrorInvalidDevicePointer;
// Synchronize to ensure all work has finished.
ihipGetTlsDefaultDevice()->waitAllStreams(); // ignores non-blocking streams, this waits for all activity to finish.
if (ptr) {
hc::accelerator acc;
hc::AmPointerInfo amPointerInfo(NULL, NULL, 0, acc, 0, 0);
am_status_t status = hc::am_memtracker_getinfo(&amPointerInfo, ptr);
if(status == AM_SUCCESS){
if(amPointerInfo._hostPointer == NULL){
hc::am_free(ptr);
hipStatus = hipSuccess;
}
}
hc::am_free(ptr);
}
return ihipLogStatus(hipStatus);
return ihipLogStatus(hipSuccess);
}
@@ -2629,20 +2620,12 @@ hipError_t hipHostFree(void* ptr)
// TODO - ensure this pointer was created by hipMallocHost and not hipMalloc
std::call_once(hip_initialized, ihipInit);
hipError_t hipStatus = hipErrorInvalidDevicePointer;
if (ptr) {
hc::accelerator acc;
hc::AmPointerInfo amPointerInfo(NULL, NULL, 0, acc, 0, 0);
am_status_t status = hc::am_memtracker_getinfo(&amPointerInfo, ptr);
if(status == AM_SUCCESS){
if(amPointerInfo._hostPointer == ptr){
hc::am_free(ptr);
hipStatus = hipSuccess;
}
}
tprintf (DB_MEM, " %s: %p\n", __func__, ptr);
hc::am_free(ptr);
}
return ihipLogStatus(hipStatus);
return ihipLogStatus(hipSuccess);
};
-4
查看文件
@@ -140,8 +140,6 @@ make_hip_executable (hipStreamL5 hipStreamL5.cpp)
make_hip_executable (hipHostGetFlags hipHostGetFlags.cpp)
make_hip_executable (hipHostRegister hipHostRegister.cpp)
make_hip_executable (hipRandomMemcpyAsync hipRandomMemcpyAsync.cpp)
make_hip_executable (hipMemoryAllocate hipMemoryAllocate.cpp)
make_test(hip_ballot " " )
make_test(hip_anyall " " )
make_test(hip_popc " " )
@@ -172,6 +170,4 @@ make_test(hipStreamL5 " ")
make_test(hipRandomMemcpyAsync " ")
#make_test(hipAPIStreamEnable " ")
#make_test(hipAPIStreamDisable " ")
make_test(hipMemoryAllocate " ")
make_hipify_test(specialFunc.cu )
-51
查看文件
@@ -1,51 +0,0 @@
/*
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANNTY OF ANY KIND, EXPRESS OR
IMPLIED, INNCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANNY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER INN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR INN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
#include"test_common.h"
#define SIZE 1024*1024*256
int main(){
float *Ad, *B, *Bd, *Bm, *C, *Cd;
B = (float*)malloc(SIZE);
hipMalloc((void**)&Ad, SIZE);
hipHostMalloc((void**)&B, SIZE);
hipHostMalloc((void**)&Bd, SIZE, hipHostMallocDefault);
hipHostMalloc((void**)&Bm, SIZE, hipHostMallocMapped);
hipHostMalloc((void**)&C, SIZE, hipHostMallocMapped);
hipHostGetDevicePointer((void**)&Cd, C, SIZE);
HIPASSERT(hipFree(Ad) == hipSuccess);
HIPASSERT(hipHostFree(Ad) == hipErrorInvalidDevicePointer);
HIPASSERT(hipFree(B) == hipErrorInvalidDevicePointer);
HIPASSERT(hipFree(Bd) == hipErrorInvalidDevicePointer);
HIPASSERT(hipFree(Bm) == hipErrorInvalidDevicePointer);
HIPASSERT(hipHostFree(Bd) == hipSuccess);
HIPASSERT(hipHostFree(Bm) == hipSuccess);
HIPASSERT(hipFree(C) == hipErrorInvalidDevicePointer);
HIPASSERT(hipFree(Cd) == hipErrorInvalidDevicePointer);
HIPASSERT(hipHostFree(C) == hipSuccess);
HIPASSERT(hipHostFree(Cd) == hipErrorInvalidDevicePointer);
HIPASSERT(hipFree(Cd) == hipErrorInvalidDevicePointer);
HIPASSERT(hipFree(NULL) == hipErrorInvalidDevicePointer);
HIPASSERT(hipHostFree(NULL) == hipErrorInvalidDevicePointer);
passed();
}